@@ -121,8 +121,6 @@ Instrument
     The measured polarization of the instrument. Valid options are:
     'uu','dd', 'ud', 'du' or 'ass' the respective number 0-3 also works.
 '''
-from numpy import *
-from genx.gui_logging import iprint
 from .lib import paratt as Paratt
 from .lib import neutron_refl as MatrixNeutron
 from .lib.instrument import *
@@ -131,7 +129,7 @@ from .lib.physical_constants import r_e, muB_to_SL
 
 # Preamble to define the parameters needed for the models outlined below:
 
-# import lib.paratt as slow_paratt
+# import core.paratt as slow_paratt
 
 ModelID='SpecNX'
 # InstrumentParameters={'Wavelength':1.54, 'Coordinates':1, 'I0':1.0, 'Sim': 0,
@@ -370,10 +368,6 @@ def specular_calcs(TwoThetaQz, sample, instrument, return_int=True):
     if ptype==instrument_string_choices['probe'][0] or ptype==0:
         R=Paratt.ReflQ(Q, instrument.getWavelength(), 1.0-r_e*sld, d, sigma, return_int=return_int)
         # print 2.82e-5*sld
-        # reload(slow_paratt)
-        # R = slow_paratt.reflq_kin(Q, instrument.getWavelength(), 1.0 - 2.82e-5 * sld, d, sigma)
-        # R = slow_paratt.reflq_pseudo_kin(Q, instrument.getWavelength(), 1.0 - 2.82e-5 * sld, d, sigma)
-        # R = slow_paratt.reflq_sra(Q, instrument.getWavelength(), 1.0 - 2.82e-5 * sld, d, sigma)
     # Ordinary Paratt Neutrons
     elif ptype==instrument_string_choices['probe'][1] or ptype==1:
         R=Paratt.ReflQ(Q, instrument.getWavelength(), 1.0-sld, d, sigma, return_int=return_int)
@@ -655,7 +649,7 @@ SimulationFunctions={'Specular': Specular,
                                                     ModelID)
 
 if __name__=='__main__':
-    from .utils import UserVars, fp, fw, bc, bw
+    from .utils import UserVars, fp, fw
     import numpy as np
 
     # BEGIN Instrument DO NOT CHANGE
