@@ -106,7 +106,8 @@ Sample
 import numpy as np
 from . import utils
 from .lib.physical_constants import r_e
-from genx.gui_logging import iprint
+from .symmetries import SymTrans
+from genx.core.custom_logging import iprint
 
 from .lib import USE_NUMBA
 if USE_NUMBA:
@@ -361,6 +362,22 @@ class Sample:
         '''
         return _fatom_eval(inst, f, element, s)
 
+    def export_xyz(self, fname):
+        from genx.version import __version__ as version
+        if not fname.endswith('.xyz'):
+            fname+='.xyz'
+        x, y, z, u, oc, el, ids = self.create_uc_output()
+        uc_a=self.unit_cell.a
+        uc_b=self.unit_cell.b
+        uc_c=self.unit_cell.c
+        c_total=uc_c*sum([sl.c for sl in self.slabs])
+        with open(fname, 'w') as fh:
+            fh.write(f'{len(x)}\n')
+            fh.write(f'# structure exported by GenX {version}, UC: a={uc_a} b={uc_b} c={c_total}\n')
+            for xi, yi, zi, eli in zip(x,y,z,el):
+                fh.write(f'{eli:3s} {uc_a*xi:-12.7f} {uc_b*yi:-12.7f} {uc_c*zi:-12.7f}\n')
+
+
 class UnitCell:
     '''Class containing the  unitcell.
     This also allows for simple crystalloraphic computing of different
@@ -499,6 +516,14 @@ class Slab:
             cpy.dy[-1]=self.dy[i]
         return cpy
 
+    def __str__(self):
+        out=f'Slab(c={self.c}, slab_oc={self.slab_oc})'
+        for i in range(len(self.id)):
+            out+=f'\n  atom {i+1}: {self.id[i]}= {self.el[i]} at '
+            out+=f'({self.x[i]}, {self.y[i]}, self.z[i]) '
+            out+=f'u={self.u[i]}, oc={self.oc[i]}, m={self.m[i]}'
+        return out
+
     def add_atom(self, id, element, x, y, z, u=0.0, oc=1.0, m=1.0):
         '''Add an atom to the slab.
 
@@ -527,7 +552,6 @@ class Slab:
         item=len(self.id)-1
         # Create the set and get functions dynamically
         for par in self.par_names:
-            p=par
             setattr(self, 'set'+id+par, self._make_set_func(par, item))
             setattr(self, 'get'+id+par, self._make_get_func(par, item))
         return AtomGroup(self, id)
@@ -1005,31 +1029,6 @@ class Instrument:
         '''
         self.rholib=rholib
 
-class SymTrans:
-    def __init__(self, P=None, t=None):
-        # TODO: Check size of arrays!
-        if P is None:
-            P=[[1, 0], [0, 1]]
-        if t is None:
-            t=[0, 0]
-        self.P=np.array(P, dtype=np.float64)
-        self.t=np.array(t, dtype=np.float64)
-
-    def trans_x(self, x, y):
-        '''transformed x coord
-        '''
-        # print self.P[0][0]*x + self.P[0][1]*y + self.t[0]
-        return self.P[0][0]*x+self.P[0][1]*y+self.t[0]
-
-    def trans_y(self, x, y):
-        '''transformed x coord
-        '''
-        # print self.P[1][0]*x + self.P[1][1]*y + self.t[1]
-        return self.P[1][0]*x+self.P[1][1]*y+self.t[1]
-
-    def apply_symmetry(self, x, y):
-        return np.dot(self.P, np.c_[x, y])+self.t
-
 # ==============================================================================
 # Utillity functions
 def scale_sim(data, sim_list, scale_func=None):
